@@ -3,7 +3,7 @@ import copy
 import requests
 from dateutil import tz
 
-from .classes import AlchemerObject, Survey, ContactList
+from .classes import AlchemerObject, ContactList, Survey
 
 
 class AlchemerSession(requests.Session):
@@ -56,7 +56,7 @@ class AlchemerSession(requests.Session):
 
     def _api_list(self, url, params):
         original_params = params
-        req_params = copy.deepcopy(params)        
+        req_params = copy.deepcopy(params)
         all_data = []
         while True:
             response = self._api_get(url=url, params=req_params)
